# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bot_api_conn_grpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='bot_api_conn_grpc.proto',
  package='bot_api_conn_grpc',
  syntax='proto3',
  serialized_options=b'\n\034io.grpc.example.bot_api_connB\021bot_api_conn_grpcP\001\242\002\003HLW',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17\x62ot_api_conn_grpc.proto\x12\x11\x62ot_api_conn_grpc\"M\n\x11SendBotMsgRequest\x12\x0e\n\x06openid\x18\x01 \x01(\t\x12\x0e\n\x06\x62ot_id\x18\x02 \x01(\t\x12\x0b\n\x03\x63md\x18\x03 \x01(\t\x12\x0b\n\x03msg\x18\x04 \x01(\t\"N\n\x12SendBotMsgResponse\x12\x0e\n\x06openid\x18\x01 \x01(\t\x12\x0e\n\x06\x62ot_id\x18\x02 \x01(\t\x12\x0b\n\x03\x63md\x18\x03 \x01(\t\x12\x0b\n\x03ret\x18\x04 \x01(\x05\"?\n\x14\x44riveEventMsgRequest\x12\x0e\n\x06openid\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\"@\n\x15\x44riveEventMsgResponse\x12\x0e\n\x06openid\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0b\n\x03ret\x18\x03 \x01(\x05\"0\n\x12\x43odeSaveMsgRequest\x12\x0e\n\x06openid\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\">\n\x13\x43odeSaveMsgResponse\x12\x0e\n\x06openid\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0b\n\x03ret\x18\x03 \x01(\x05\"0\n\x12\x43odeTestMsgRequest\x12\x0e\n\x06openid\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\">\n\x13\x43odeTestMsgResponse\x12\x0e\n\x06openid\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0b\n\x03ret\x18\x03 \x01(\x05\".\n\x10\x43odePcMsgRequest\x12\x0e\n\x06openid\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"<\n\x11\x43odePcMsgResponse\x12\x0e\n\x06openid\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0b\n\x03ret\x18\x03 \x01(\x05\x32\xed\x03\n\x0e\x42otApiConnGrpc\x12[\n\nSendBotMsg\x12$.bot_api_conn_grpc.SendBotMsgRequest\x1a%.bot_api_conn_grpc.SendBotMsgResponse\"\x00\x12\x64\n\rDriveEventMsg\x12\'.bot_api_conn_grpc.DriveEventMsgRequest\x1a(.bot_api_conn_grpc.DriveEventMsgResponse\"\x00\x12^\n\x0b\x43odeSaveMsg\x12%.bot_api_conn_grpc.CodeSaveMsgRequest\x1a&.bot_api_conn_grpc.CodeSaveMsgResponse\"\x00\x12^\n\x0b\x43odeTestMsg\x12%.bot_api_conn_grpc.CodeTestMsgRequest\x1a&.bot_api_conn_grpc.CodeTestMsgResponse\"\x00\x12X\n\tCodePcMsg\x12#.bot_api_conn_grpc.CodePcMsgRequest\x1a$.bot_api_conn_grpc.CodePcMsgResponse\"\x00\x42\x39\n\x1cio.grpc.example.bot_api_connB\x11\x62ot_api_conn_grpcP\x01\xa2\x02\x03HLWb\x06proto3'
)




_SENDBOTMSGREQUEST = _descriptor.Descriptor(
  name='SendBotMsgRequest',
  full_name='bot_api_conn_grpc.SendBotMsgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='openid', full_name='bot_api_conn_grpc.SendBotMsgRequest.openid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bot_id', full_name='bot_api_conn_grpc.SendBotMsgRequest.bot_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cmd', full_name='bot_api_conn_grpc.SendBotMsgRequest.cmd', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='bot_api_conn_grpc.SendBotMsgRequest.msg', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=123,
)


_SENDBOTMSGRESPONSE = _descriptor.Descriptor(
  name='SendBotMsgResponse',
  full_name='bot_api_conn_grpc.SendBotMsgResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='openid', full_name='bot_api_conn_grpc.SendBotMsgResponse.openid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bot_id', full_name='bot_api_conn_grpc.SendBotMsgResponse.bot_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cmd', full_name='bot_api_conn_grpc.SendBotMsgResponse.cmd', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ret', full_name='bot_api_conn_grpc.SendBotMsgResponse.ret', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=203,
)


_DRIVEEVENTMSGREQUEST = _descriptor.Descriptor(
  name='DriveEventMsgRequest',
  full_name='bot_api_conn_grpc.DriveEventMsgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='openid', full_name='bot_api_conn_grpc.DriveEventMsgRequest.openid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='bot_api_conn_grpc.DriveEventMsgRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='msg', full_name='bot_api_conn_grpc.DriveEventMsgRequest.msg', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=268,
)


_DRIVEEVENTMSGRESPONSE = _descriptor.Descriptor(
  name='DriveEventMsgResponse',
  full_name='bot_api_conn_grpc.DriveEventMsgResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='openid', full_name='bot_api_conn_grpc.DriveEventMsgResponse.openid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='bot_api_conn_grpc.DriveEventMsgResponse.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ret', full_name='bot_api_conn_grpc.DriveEventMsgResponse.ret', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=334,
)


_CODESAVEMSGREQUEST = _descriptor.Descriptor(
  name='CodeSaveMsgRequest',
  full_name='bot_api_conn_grpc.CodeSaveMsgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='openid', full_name='bot_api_conn_grpc.CodeSaveMsgRequest.openid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='bot_api_conn_grpc.CodeSaveMsgRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=336,
  serialized_end=384,
)


_CODESAVEMSGRESPONSE = _descriptor.Descriptor(
  name='CodeSaveMsgResponse',
  full_name='bot_api_conn_grpc.CodeSaveMsgResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='openid', full_name='bot_api_conn_grpc.CodeSaveMsgResponse.openid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='bot_api_conn_grpc.CodeSaveMsgResponse.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ret', full_name='bot_api_conn_grpc.CodeSaveMsgResponse.ret', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=448,
)


_CODETESTMSGREQUEST = _descriptor.Descriptor(
  name='CodeTestMsgRequest',
  full_name='bot_api_conn_grpc.CodeTestMsgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='openid', full_name='bot_api_conn_grpc.CodeTestMsgRequest.openid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='bot_api_conn_grpc.CodeTestMsgRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=450,
  serialized_end=498,
)


_CODETESTMSGRESPONSE = _descriptor.Descriptor(
  name='CodeTestMsgResponse',
  full_name='bot_api_conn_grpc.CodeTestMsgResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='openid', full_name='bot_api_conn_grpc.CodeTestMsgResponse.openid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='bot_api_conn_grpc.CodeTestMsgResponse.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ret', full_name='bot_api_conn_grpc.CodeTestMsgResponse.ret', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=500,
  serialized_end=562,
)


_CODEPCMSGREQUEST = _descriptor.Descriptor(
  name='CodePcMsgRequest',
  full_name='bot_api_conn_grpc.CodePcMsgRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='openid', full_name='bot_api_conn_grpc.CodePcMsgRequest.openid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='bot_api_conn_grpc.CodePcMsgRequest.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=564,
  serialized_end=610,
)


_CODEPCMSGRESPONSE = _descriptor.Descriptor(
  name='CodePcMsgResponse',
  full_name='bot_api_conn_grpc.CodePcMsgResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='openid', full_name='bot_api_conn_grpc.CodePcMsgResponse.openid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='bot_api_conn_grpc.CodePcMsgResponse.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ret', full_name='bot_api_conn_grpc.CodePcMsgResponse.ret', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=612,
  serialized_end=672,
)

DESCRIPTOR.message_types_by_name['SendBotMsgRequest'] = _SENDBOTMSGREQUEST
DESCRIPTOR.message_types_by_name['SendBotMsgResponse'] = _SENDBOTMSGRESPONSE
DESCRIPTOR.message_types_by_name['DriveEventMsgRequest'] = _DRIVEEVENTMSGREQUEST
DESCRIPTOR.message_types_by_name['DriveEventMsgResponse'] = _DRIVEEVENTMSGRESPONSE
DESCRIPTOR.message_types_by_name['CodeSaveMsgRequest'] = _CODESAVEMSGREQUEST
DESCRIPTOR.message_types_by_name['CodeSaveMsgResponse'] = _CODESAVEMSGRESPONSE
DESCRIPTOR.message_types_by_name['CodeTestMsgRequest'] = _CODETESTMSGREQUEST
DESCRIPTOR.message_types_by_name['CodeTestMsgResponse'] = _CODETESTMSGRESPONSE
DESCRIPTOR.message_types_by_name['CodePcMsgRequest'] = _CODEPCMSGREQUEST
DESCRIPTOR.message_types_by_name['CodePcMsgResponse'] = _CODEPCMSGRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SendBotMsgRequest = _reflection.GeneratedProtocolMessageType('SendBotMsgRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDBOTMSGREQUEST,
  '__module__' : 'bot_api_conn_grpc_pb2'
  # @@protoc_insertion_point(class_scope:bot_api_conn_grpc.SendBotMsgRequest)
  })
_sym_db.RegisterMessage(SendBotMsgRequest)

SendBotMsgResponse = _reflection.GeneratedProtocolMessageType('SendBotMsgResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDBOTMSGRESPONSE,
  '__module__' : 'bot_api_conn_grpc_pb2'
  # @@protoc_insertion_point(class_scope:bot_api_conn_grpc.SendBotMsgResponse)
  })
_sym_db.RegisterMessage(SendBotMsgResponse)

DriveEventMsgRequest = _reflection.GeneratedProtocolMessageType('DriveEventMsgRequest', (_message.Message,), {
  'DESCRIPTOR' : _DRIVEEVENTMSGREQUEST,
  '__module__' : 'bot_api_conn_grpc_pb2'
  # @@protoc_insertion_point(class_scope:bot_api_conn_grpc.DriveEventMsgRequest)
  })
_sym_db.RegisterMessage(DriveEventMsgRequest)

DriveEventMsgResponse = _reflection.GeneratedProtocolMessageType('DriveEventMsgResponse', (_message.Message,), {
  'DESCRIPTOR' : _DRIVEEVENTMSGRESPONSE,
  '__module__' : 'bot_api_conn_grpc_pb2'
  # @@protoc_insertion_point(class_scope:bot_api_conn_grpc.DriveEventMsgResponse)
  })
_sym_db.RegisterMessage(DriveEventMsgResponse)

CodeSaveMsgRequest = _reflection.GeneratedProtocolMessageType('CodeSaveMsgRequest', (_message.Message,), {
  'DESCRIPTOR' : _CODESAVEMSGREQUEST,
  '__module__' : 'bot_api_conn_grpc_pb2'
  # @@protoc_insertion_point(class_scope:bot_api_conn_grpc.CodeSaveMsgRequest)
  })
_sym_db.RegisterMessage(CodeSaveMsgRequest)

CodeSaveMsgResponse = _reflection.GeneratedProtocolMessageType('CodeSaveMsgResponse', (_message.Message,), {
  'DESCRIPTOR' : _CODESAVEMSGRESPONSE,
  '__module__' : 'bot_api_conn_grpc_pb2'
  # @@protoc_insertion_point(class_scope:bot_api_conn_grpc.CodeSaveMsgResponse)
  })
_sym_db.RegisterMessage(CodeSaveMsgResponse)

CodeTestMsgRequest = _reflection.GeneratedProtocolMessageType('CodeTestMsgRequest', (_message.Message,), {
  'DESCRIPTOR' : _CODETESTMSGREQUEST,
  '__module__' : 'bot_api_conn_grpc_pb2'
  # @@protoc_insertion_point(class_scope:bot_api_conn_grpc.CodeTestMsgRequest)
  })
_sym_db.RegisterMessage(CodeTestMsgRequest)

CodeTestMsgResponse = _reflection.GeneratedProtocolMessageType('CodeTestMsgResponse', (_message.Message,), {
  'DESCRIPTOR' : _CODETESTMSGRESPONSE,
  '__module__' : 'bot_api_conn_grpc_pb2'
  # @@protoc_insertion_point(class_scope:bot_api_conn_grpc.CodeTestMsgResponse)
  })
_sym_db.RegisterMessage(CodeTestMsgResponse)

CodePcMsgRequest = _reflection.GeneratedProtocolMessageType('CodePcMsgRequest', (_message.Message,), {
  'DESCRIPTOR' : _CODEPCMSGREQUEST,
  '__module__' : 'bot_api_conn_grpc_pb2'
  # @@protoc_insertion_point(class_scope:bot_api_conn_grpc.CodePcMsgRequest)
  })
_sym_db.RegisterMessage(CodePcMsgRequest)

CodePcMsgResponse = _reflection.GeneratedProtocolMessageType('CodePcMsgResponse', (_message.Message,), {
  'DESCRIPTOR' : _CODEPCMSGRESPONSE,
  '__module__' : 'bot_api_conn_grpc_pb2'
  # @@protoc_insertion_point(class_scope:bot_api_conn_grpc.CodePcMsgResponse)
  })
_sym_db.RegisterMessage(CodePcMsgResponse)


DESCRIPTOR._options = None

_BOTAPICONNGRPC = _descriptor.ServiceDescriptor(
  name='BotApiConnGrpc',
  full_name='bot_api_conn_grpc.BotApiConnGrpc',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=675,
  serialized_end=1168,
  methods=[
  _descriptor.MethodDescriptor(
    name='SendBotMsg',
    full_name='bot_api_conn_grpc.BotApiConnGrpc.SendBotMsg',
    index=0,
    containing_service=None,
    input_type=_SENDBOTMSGREQUEST,
    output_type=_SENDBOTMSGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DriveEventMsg',
    full_name='bot_api_conn_grpc.BotApiConnGrpc.DriveEventMsg',
    index=1,
    containing_service=None,
    input_type=_DRIVEEVENTMSGREQUEST,
    output_type=_DRIVEEVENTMSGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CodeSaveMsg',
    full_name='bot_api_conn_grpc.BotApiConnGrpc.CodeSaveMsg',
    index=2,
    containing_service=None,
    input_type=_CODESAVEMSGREQUEST,
    output_type=_CODESAVEMSGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CodeTestMsg',
    full_name='bot_api_conn_grpc.BotApiConnGrpc.CodeTestMsg',
    index=3,
    containing_service=None,
    input_type=_CODETESTMSGREQUEST,
    output_type=_CODETESTMSGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CodePcMsg',
    full_name='bot_api_conn_grpc.BotApiConnGrpc.CodePcMsg',
    index=4,
    containing_service=None,
    input_type=_CODEPCMSGREQUEST,
    output_type=_CODEPCMSGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BOTAPICONNGRPC)

DESCRIPTOR.services_by_name['BotApiConnGrpc'] = _BOTAPICONNGRPC

# @@protoc_insertion_point(module_scope)
